"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pluginApollo = void 0;
const graphql_js_tree_1 = require("graphql-js-tree");
const pluginApolloOps = ({ queryName, operation }) => {
    const capitalized = operation[0].toUpperCase() + operation.slice(1);
    const zeusOperation = operation === 'LazyQuery' ? graphql_js_tree_1.OperationType.query : operation;
    return {
        queryName,
        operation,
        ts: `export function useTyped${capitalized}<Z extends ValueTypes[O], O extends "${queryName}", SCLR extends ScalarDefinition>(
  ${operation}: Z | ValueTypes[O],
  options?:{
    apolloOptions?: ${capitalized}HookOptions<InputType<GraphQLTypes[O], Z, SCLR>>,
    operationOptions?: OperationOptions,
    scalars?: SCLR
  }
) {
  return use${capitalized}<InputType<GraphQLTypes[O], Z, SCLR>>(gql(Zeus("${zeusOperation}",${operation}, {
    operationOptions: options?.operationOptions,
    scalars: options?.scalars
  })), options?.apolloOptions);
}`,
    };
};
const pluginApollo = ({ tree, esModule }) => {
    const operationNodes = tree.nodes.filter((n) => n.type.operations);
    const opsFunctions = operationNodes.flatMap((n) => n.type.operations.map((o) => pluginApolloOps({ queryName: n.name, operation: o })));
    for (const [index, o] of opsFunctions.entries()) {
        if (o.operation === graphql_js_tree_1.OperationType.query) {
            opsFunctions.splice(index + 1, 0, pluginApolloOps({ queryName: o.queryName, operation: 'LazyQuery' }));
            break;
        }
    }
    const o = opsFunctions.reduce((a, b) => {
        a.ts = [a.ts, b.ts].join('\n');
        return a;
    }, { ts: '' });
    const capitalizedOps = opsFunctions.map((o) => o.operation[0].toUpperCase() + o.operation.slice(1));
    const jsDefsImports = [];
    if (capitalizedOps.includes('LazyQuery')) {
        jsDefsImports.push('QueryTuple');
    }
    if (capitalizedOps.includes('Query')) {
        jsDefsImports.push('QueryResult');
    }
    if (capitalizedOps.includes('Mutation')) {
        jsDefsImports.push('MutationTuple');
    }
    return {
        ts: `/* eslint-disable */

import { Zeus, GraphQLTypes, InputType, ValueTypes, OperationOptions, ScalarDefinition } from './index${esModule ? '.js' : ''}';
import { gql, ${capitalizedOps.map((o) => `use${o}`).join(', ')} } from '@apollo/client';
import type { ${capitalizedOps.map((o) => `${o}HookOptions`).join(', ')} } from '@apollo/client';

${o.ts}
`,
    };
};
exports.pluginApollo = pluginApollo;
//# sourceMappingURL=index.js.map